@@ -40,14 +40,14 @@ class Q_DECL_EXPORT BridgeWidget : public SettingWidget
     Q_OBJECT
 public:
     explicit BridgeWidget(const QString & masterUuid, const NetworkManager::Setting::Ptr &setting = NetworkManager::Setting::Ptr(),
-                 QWidget* parent = 0, Qt::WindowFlags f = 0);
-    virtual ~BridgeWidget();
+                 QWidget* parent = nullptr, Qt::WindowFlags f = {});
+    ~BridgeWidget() override;
 
-    void loadConfig(const NetworkManager::Setting::Ptr &setting) Q_DECL_OVERRIDE;
+    void loadConfig(const NetworkManager::Setting::Ptr &setting) override;
 
-    QVariantMap setting() const Q_DECL_OVERRIDE;
+    QVariantMap setting() const override;
 
-    virtual bool isValid() const Q_DECL_OVERRIDE;
+    bool isValid() const override;
 
 private Q_SLOTS:
     void addBridge(QAction * action);
