@@ -36,9 +36,9 @@ public:
 
     enum ItemType { UnavailableConnection, AvailableConnection, AvailableAccessPoint };
 
-    explicit NetworkModelItem(QObject *parent = 0);
-    explicit NetworkModelItem(const NetworkModelItem *item, QObject *parent = 0);
-    virtual ~NetworkModelItem();
+    explicit NetworkModelItem(QObject *parent = nullptr);
+    explicit NetworkModelItem(const NetworkModelItem *item, QObject *parent = nullptr);
+    ~NetworkModelItem() override;
 
     QString activeConnectionPath() const;
     void setActiveConnectionPath(const QString &path);
@@ -108,19 +108,28 @@ public:
     QString vpnType() const;
     void setVpnType(const QString &type);
 
+    qulonglong rxBytes() const;
+    void setRxBytes(qulonglong bytes);
+
+    qulonglong txBytes() const;
+    void setTxBytes(qulonglong bytes);
+
     bool operator==(const NetworkModelItem *item) const;
 
 public Q_SLOTS:
-    void updateDetails();
+    void invalidateDetails();
 
 private:
+    void updateDetails() const;
+
     QString m_activeConnectionPath;
     QString m_connectionPath;
     NetworkManager::ActiveConnection::State m_connectionState;
     QString m_devicePath;
     QString m_deviceName;
     NetworkManager::Device::State m_deviceState;
-    QStringList m_details;
+    mutable QStringList m_details;
+    mutable bool m_detailsValid;
     bool m_duplicate;
     NetworkManager::WirelessSetting::NetworkMode m_mode;
     QString m_name;
@@ -134,6 +143,8 @@ private:
     QString m_uuid;
     QString m_vpnType;
     NetworkManager::VpnConnection::State m_vpnState;
+    qulonglong m_rxBytes;
+    qulonglong m_txBytes;
 };
 
 #endif // PLASMA_NM_MODEL_NETWORK_MODEL_ITEM_H
